use iced::theme;
use iced::widget::{
    checkbox, column, container, horizontal_space, image, radio, row, scrollable, slider, text,
    text_input, toggler, vertical_space,
};
use iced::widget::{Button, Column, Container, Slider};
use iced::{alignment, Element, Length, Sandbox, Settings};

mod comm;
mod keyboard;

struct Gui {
    password: String,
}

#[derive(Debug, Clone)]
enum Message {
    Pressed,
    PasswordChanged(String),
}

impl Sandbox for Gui {
    type Message = Message;

    fn new() -> Self {
        Gui {password: "".to_owned()}
    }

    fn update(&mut self, event: Message) {
        match event {
            Message::PasswordChanged(p) => self.password = p,
            Message::Pressed => println!("Pressed")
        }
    }

    fn view(&self) -> Element<Message> {
        let content: Element<_> = column![
            text_input("Enter password", &self.password, Message::PasswordChanged)
                .password()
                .size(30),
            button("Connect")
                .style(theme::Button::Primary)
                .on_press(Message::Pressed),
        ]
        .max_width(540)
        .spacing(20)
        .padding(20)
        .into();

        content
    }

    fn title(&self) -> String {
        "gui".to_owned()
    }
}

fn button<'a, Message: Clone>(label: &str) -> Button<'a, Message> {
    iced::widget::button(text(label).horizontal_alignment(alignment::Horizontal::Center))
        .padding(12)
}

fn millis_to_string(millis: u32) -> String {
    let seconds = (millis as f64) / 1000.0;
    let formatted = format!("{:.2}", seconds);
    formatted.replace(".", ",")
}

fn handle_time(time: u32) -> Result<(),()> {
    println!("Got time: {}", time);
    let time_with_comma = millis_to_string(time);

    println!("Trying to type {time_with_comma}");
    keyboard::type_text(&time_with_comma)?;
    keyboard::click_tab()?;
    keyboard::click_tab()?;
    Ok(())
}

fn main() {
    let password = "test";
    let broker_domain = "broker.emqx.io";

    let c = comm::Comm::new(&broker_domain, &password, handle_time).unwrap();

    //Gui::run(Settings::default());

    println!("Processing requests...");
    c.listen();
}
